@@ -24,7 +24,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
-(* $Id: postgresql.mli,v 1.2 2004/01/29 22:46:09 mottl Exp $ *)
+(* $Id: postgresql.mli,v 1.3 2004/08/05 19:00:55 mottl Exp $ *)
 
 (** Client-interface to the PostgreSQL database. *)
 
@@ -32,6 +32,76 @@
 
 (** {6 Types} *)
 
+(** Object ID (= Postgresql type of an object) *)
+type oid = int
+
+(** Handle for large objects *)
+type large_object
+
+(** Type of fields *)
+type ftype =
+  | BOOL
+  | BYTEA
+  | CHAR
+  | NAME
+  | INT8
+  | INT2
+  | INT2VECTOR
+  | INT4
+  | REGPROC
+  | TEXT
+  | OID
+  | TID
+  | XID
+  | CID
+  | OIDVECTOR
+  | POINT
+  | LSEG
+  | PATH
+  | BOX
+  | POLYGON
+  | LINE
+  | FLOAT4
+  | FLOAT8
+  | ABSTIME
+  | RELTIME
+  | TINTERVAL
+  | UNKNOWN
+  | CIRCLE
+  | CASH
+  | MACADDR
+  | INET
+  | CIDR
+  | ACLITEM
+  | BPCHAR
+  | VARCHAR
+  | DATE
+  | TIME
+  | TIMESTAMP
+  | TIMESTAMPTZ
+  | INTERVAL
+  | TIMETZ
+  | BIT
+  | VARBIT
+  | NUMERIC
+  | REFCURSOR
+  | REGPROCEDURE
+  | REGOPER
+  | REGOPERATOR
+  | REGCLASS
+  | REGTYPE
+  | RECORD
+  | CSTRING
+  | ANY
+  | ANYARRAY
+  | VOID
+  | TRIGGER
+  | LANGUAGE_HANDLER
+  | INTERNAL
+  | OPAQUE
+  | ANYELEMENT
+
+
 (** Status of command/query results *)
 type result_status =
   | Empty_query     (** String sent to the backend was empty *)
@@ -80,6 +150,12 @@ exception Error of error
 val string_of_error : error -> string
 (** [string_of_error error] convert [error] to a human-readable message *)
 
+(** [Oid oid] conversion from an oid to an ftype encountered an unknown [oid] *)
+exception Oid of oid
+
+(** [InternalError error] indicates an internal [error] *)
+exception InternalError of string
+
 
 (** {6 Utility functions}*)
 
@@ -98,15 +174,24 @@ val escape_bytea : ?pos : int -> ?len : int -> string -> string
 external unescape_bytea : string -> string = "PQunescapeBytea_stub"
 (** [unescape_bytea str] unescapes binary string [str]. *)
 
+external ftype_of_oid : oid -> ftype = "ftype_of_oid_stub"
+(** [ftype_of_oid oid] converts [oid] to an [ftype]. *)
+
+external oid_of_ftype : ftype -> oid = "oid_of_ftype_stub"
+(** [oid_of_ftype ftype] converts [ftype] to an [oid]. *)
+
+val string_of_ftype : ftype -> string
+(** [string_of_ftype ftype] converts [ftype] to a string. *)
+
+val ftype_of_string : string -> ftype
+(** [string_of_ftype ftype] converts [ftype] to a string. *)
+
 
 (** {6 Handling results of commands and queries} *)
 
 external result_status : result_status -> string = "PQresStatus_stub"
 (** [result_status stat] convert status [stat] to a human-readable message *)
 
-type oid  (** Object ID (= Postgresql type of an object) *)
-type large_object  (** Handle for large objects *)
-
 val invalid_oid : oid
 (** [invalid_oid] invalid Oid. *)
 
@@ -138,8 +223,9 @@ class type result = object
   (** [#fnumber field] @return the index of the field named [field].
       @raise Not_found if no such named field. *)
 
-  method ftype : int -> oid
+  method ftype : int -> ftype
   (** [#ftype n] @return the type of the [n]th field.
+      @raise Oid if there was no corresponding ftype for the internal [oid].
       @raise Error if field out of range. *)
 
   method fmod : int -> int
@@ -183,7 +269,7 @@ class type result = object
   (** [#cmd_tuples] @return number of rows affected by the SQL command. *)
 
   method oid_value : oid
-  (** [#cmd_tuples] @return the object ID of the inserted row, if the SQL
+  (** [#cmd_tuples] @return the object ID of the inserted row if the SQL
       command was an INSERT that inserted exactly one row into a table
       that has OIDs. Otherwise, returns [invalid_oid]. *)
 
@@ -236,16 +322,16 @@ external conndefaults : unit -> conninfo_option array = "PQconndefaults_stub"
     When [conninfo] is given, it will be used instead of all other
     optional arguments. *)
 class connection :
-  ?host : string ->  (** Default: none *)
-  ?hostaddr : string ->  (** Default: none *)
-  ?port : string  ->  (** Default: none *)
-  ?dbname : string ->  (** Default: none *)
-  ?user : string ->  (** Default: none *)
-  ?password : string ->  (** Default: none *)
-  ?options : string ->  (** Default: none *)
-  ?tty : string ->  (** Default: none *)
-  ?requiressl : string ->  (** Default: none *)
-  ?conninfo : string ->  (** Default: none *)
+  ?host : string ->  (* Default: none *)
+  ?hostaddr : string ->  (* Default: none *)
+  ?port : string  ->  (* Default: none *)
+  ?dbname : string ->  (* Default: none *)
+  ?user : string ->  (* Default: none *)
+  ?password : string ->  (* Default: none *)
+  ?options : string ->  (* Default: none *)
+  ?tty : string ->  (* Default: none *)
+  ?requiressl : string ->  (* Default: none *)
+  ?conninfo : string ->  (* Default: none *)
   unit ->
   (** @raise Error if there is a connection failure. *)
 object
